Calculate the soil nitrogen supplying capacity in the Netherlands
osi_c_nitrogen_nl.RdThis function calculates the NLV (nitrogen producing capacity) for the soil
Arguments
- B_LU
(numeric) The crop code from the BRP
- B_SOILTYPE_AGR
(character) The agricultural type of soil
- A_SOM_LOI
(numeric) The percentage organic matter in the soil
- A_N_RT
(numeric) The organic nitrogen content of the soil in mg N / kg
- unitcheck
(character) Option to switch off unit checks (TRUE or FALSE)