Skip to contents

This function calculates the phosphorus availability.

Usage

osi_c_phosphor_fi(
  B_LU,
  B_TEXTURE_USDA,
  A_P_AAA,
  A_C_OF = 0.5,
  unitcheck = TRUE
)

Arguments

B_LU

(character) The crop code

B_TEXTURE_USDA

(character) The soil texture according to USDA classification system

A_P_AAA

(numeric) The exchangeable P-content of the soil measured via acid ammonium acetate extraction (mg P/kg)

A_C_OF

(numeric) The organic carbon content in the soil (g C / kg)

unitcheck

(character) Option to switch off unit checks (TRUE or FALSE)

Value

The phosphorus availability index in Finland estimated from extractable phosphorus. A numeric value.

Examples

osi_c_phosphor_fi(B_LU = '3301000000', B_TEXTURE_USDA = 'Si',
A_P_AAA = 45,A_C_OF=1.5)
#> [1] 0.9997505