Skip to contents

This function calculates the phosphorus availability.

Usage

osi_c_phosphor_no(A_P_AL, B_LU = NA_character_, unitcheck = TRUE)

Arguments

A_P_AL

(numeric) The exchangeable P-content of the soil measured via Ammonium Lactate (mg P/ kg)

B_LU

(character) The crop code

unitcheck

(character) Option to switch off unit checks (TRUE or FALSE)

Value

The phosphorus availability index in Norway estimated from extractable phosphorus. A numeric value.

Examples

osi_c_phosphor_no(B_LU = '3301000000', A_P_AL = 50)
#> [1] 0.9544199