Linking table between crops and different functions in OBIC
osi_crops.RdThis table helps to link the different crops in the OBIC functions with the crops selected by the user
osi_crops.RdThis table helps to link the different crops in the OBIC functions with the crops selected by the user