Calculate crumbleability index in the topsoil for all EU countries
osi_p_crumbleability.RdThis function calculates the crumbleability index
Arguments
- B_LU
(numeric) The crop code
- A_CLAY_MI
(numeric) The clay content of the soil (%)
- A_SOM_LOI
(numeric) The organic matter content of the soil (%)
- A_PH_CC
(numeric) The pH measured in CaCl2
- B_COUNTRY
(character) The country code
- pwarning
(boolean) Option to print a warning rather than error (stop) message for input checks (TRUE or FALSE)