Calculate the Cu availability index for agricultural soils in Romania
osi_c_copper_ro.RdThis function calculates the Cu availability of a soil, using the agronomic index used in Romania
osi_c_copper_ro.RdThis function calculates the Cu availability of a soil, using the agronomic index used in Romania