Calculate the magnesium availability index in Italy
osi_c_magnesium_it.RdThis function calculates the magnesium availability.
Arguments
- B_LU
(character) The crop code
- A_MG_CO_PO
(numeric) The exchangeable Mg-content of the soil measured via Cohex extracton, percentage occupation at CEC (%)
- A_K_CO_PO
(numeric) The exchangeable K-content of the soil measured via Cohex extracton, percentage occupation at CEC (%)
- unitcheck
(character) Option to switch off unit checks (TRUE or FALSE)