Calculate the Zn availability index for agricultural soils in Romenia
osi_c_zinc_ro.RdThis function calculates the Zn availability of a soil, using the agronomic index used in RO.
Arguments
- B_LU
(character) crop type
- A_PH_WA
(numeric) pH measured in water (-)
- A_P_AL
(numeric) The P-content of the soil extracted with ammonium lactate (mg P / kg)
- A_ZN_EDTA
(numeric) Zn content measured in EDTA, pH 8.6, with ammonium carbonate (mg / kg)
- unitcheck
(character) Option to switch off unit checks (TRUE or FALSE)