Wrapper function to test euosi input variables for the correct input values or options
osi_checkvar.RdThis function is a wrapper around the function osi_checkvarfun and allows the user to print warning messages
Arguments
- parm
(list) The osi parameter - value combination to be checked
- fname
(character) The name of the function where the check is done
- na_allowed
(character) Are NA allowed in categorial inputs (TRUE or FALSE)
- unitcheck
(boolean) Option to switch off unit checks (TRUE or FALSE)
- pwarning
(boolean) Option to print a warning rather than error (stop) message (TRUE or FALSE)