Estimate agricultural soil type classification used in the Netherlands
Usage
osi_get_SOILTYPE_AGR(A_CLAY_MI, A_SAND_MI, A_SOM_LOI, A_PH_CC)
Arguments
- A_CLAY_MI
(numeric) Clay content (%)
- A_SAND_MI
(numeric) Silt content (%)
- A_SOM_LOI
(numeric) The organic matter content of the soil (%)
- A_PH_CC
(numeric) The acidity of the soil, measured in 0.01M CaCl2 (-)
Value
agricultural soil type according to the Dutch classification system